import functools

import click

from bpkio_cli.utils.urls import validate_ipv4_or_domain


# Common parameters for READ and POLL
def url_options(fn):
    @click.option(
        "-s",
        "--sub",
        type=int,
        default=None,
        help="For HLS, read a sub-playlist (by index - as given by the `read ID --table` option with the main playlist)",
    )
    @click.option(
        "-u",
        "--url",
        type=str,
        default=None,
        help="Full URL of URL sub-path (for asset catalogs) to fetch",
    )
    @click.option(
        "-f",
        "--fqdn",
        type=str,
        default=None,
        is_flag=False,
        flag_value="SELECT",
        help="FQDN to use instead of the resource's own. Typically to go through a CDN",
        callback=validate_fqdn,
    )
    @functools.wraps(fn)
    def wrapper(*args, **kwargs):
        return fn(*args, **kwargs)

    return wrapper


def validate_fqdn(ctx, param, value):
    if value and value != "SELECT":
        valid = validate_ipv4_or_domain(value)
        if not valid:
            raise click.BadParameter("FQDN must be a valid IPv4 or domain name")
    return value